N_("Africa/Abidjan");
N_("Africa/Algiers");
N_("Africa/Bissau");
N_("Africa/Cairo");
N_("Africa/Casablanca");
N_("Africa/Ceuta");
N_("Africa/El_Aaiun");
N_("Africa/Johannesburg");
N_("Africa/Juba");
N_("Africa/Khartoum");
N_("Africa/Lagos");
N_("Africa/Maputo");
N_("Africa/Monrovia");
N_("Africa/Nairobi");
N_("Africa/Ndjamena");
N_("Africa/Sao_Tome");
N_("Africa/Tripoli");
N_("Africa/Tunis");
N_("Africa/Windhoek");
N_("America/Adak");
N_("America/Anchorage");
N_("America/Araguaina");
N_("America/Argentina/Buenos_Aires");
N_("America/Argentina/Catamarca");
N_("America/Argentina/Cordoba");
N_("America/Argentina/Jujuy");
N_("America/Argentina/La_Rioja");
N_("America/Argentina/Mendoza");
N_("America/Argentina/Rio_Gallegos");
N_("America/Argentina/Salta");
N_("America/Argentina/San_Juan");
N_("America/Argentina/San_Luis");
N_("America/Argentina/Tucuman");
N_("America/Argentina/Ushuaia");
N_("America/Asuncion");
N_("America/Bahia");
N_("America/Bahia_Banderas");
N_("America/Barbados");
N_("America/Belem");
N_("America/Belize");
N_("America/Boa_Vista");
N_("America/Bogota");
N_("America/Boise");
N_("America/Cambridge_Bay");
N_("America/Campo_Grande");
N_("America/Cancun");
N_("America/Caracas");
N_("America/Cayenne");
N_("America/Chicago");
N_("America/Chihuahua");
N_("America/Ciudad_Juarez");
N_("America/Costa_Rica");
N_("America/Cuiaba");
N_("America/Danmarkshavn");
N_("America/Dawson");
N_("America/Dawson_Creek");
N_("America/Denver");
N_("America/Detroit");
N_("America/Edmonton");
N_("America/Eirunepe");
N_("America/El_Salvador");
N_("America/Fort_Nelson");
N_("America/Fortaleza");
N_("America/Glace_Bay");
N_("America/Goose_Bay");
N_("America/Grand_Turk");
N_("America/Guatemala");
N_("America/Guayaquil");
N_("America/Guyana");
N_("America/Halifax");
N_("America/Havana");
N_("America/Hermosillo");
N_("America/Indiana/Indianapolis");
N_("America/Indiana/Knox");
N_("America/Indiana/Marengo");
N_("America/Indiana/Petersburg");
N_("America/Indiana/Tell_City");
N_("America/Indiana/Vevay");
N_("America/Indiana/Vincennes");
N_("America/Indiana/Winamac");
N_("America/Inuvik");
N_("America/Iqaluit");
N_("America/Jamaica");
N_("America/Juneau");
N_("America/Kentucky/Louisville");
N_("America/Kentucky/Monticello");
N_("America/La_Paz");
N_("America/Lima");
N_("America/Los_Angeles");
N_("America/Maceio");
N_("America/Managua");
N_("America/Manaus");
N_("America/Martinique");
N_("America/Matamoros");
N_("America/Mazatlan");
N_("America/Menominee");
N_("America/Merida");
N_("America/Metlakatla");
N_("America/Mexico_City");
N_("America/Miquelon");
N_("America/Moncton");
N_("America/Monterrey");
N_("America/Montevideo");
N_("America/New_York");
N_("America/Nome");
N_("America/Noronha");
N_("America/North_Dakota/Beulah");
N_("America/North_Dakota/Center");
N_("America/North_Dakota/New_Salem");
N_("America/Nuuk");
N_("America/Ojinaga");
N_("America/Panama");
N_("America/Paramaribo");
N_("America/Phoenix");
N_("America/Port-au-Prince");
N_("America/Porto_Velho");
N_("America/Puerto_Rico");
N_("America/Punta_Arenas");
N_("America/Rankin_Inlet");
N_("America/Recife");
N_("America/Regina");
N_("America/Resolute");
N_("America/Rio_Branco");
N_("America/Santarem");
N_("America/Santiago");
N_("America/Santo_Domingo");
N_("America/Sao_Paulo");
N_("America/Scoresbysund");
N_("America/Sitka");
N_("America/St_Johns");
N_("America/Swift_Current");
N_("America/Tegucigalpa");
N_("America/Thule");
N_("America/Tijuana");
N_("America/Toronto");
N_("America/Vancouver");
N_("America/Whitehorse");
N_("America/Winnipeg");
N_("America/Yakutat");
N_("Antarctica/Casey");
N_("Antarctica/Davis");
N_("Antarctica/Macquarie");
N_("Antarctica/Mawson");
N_("Antarctica/Palmer");
N_("Antarctica/Rothera");
N_("Antarctica/Troll");
N_("Antarctica/Vostok");
N_("Asia/Almaty");
N_("Asia/Amman");
N_("Asia/Anadyr");
N_("Asia/Aqtau");
N_("Asia/Aqtobe");
N_("Asia/Ashgabat");
N_("Asia/Atyrau");
N_("Asia/Baghdad");
N_("Asia/Baku");
N_("Asia/Bangkok");
N_("Asia/Barnaul");
N_("Asia/Beirut");
N_("Asia/Bishkek");
N_("Asia/Chita");
N_("Asia/Colombo");
N_("Asia/Damascus");
N_("Asia/Dhaka");
N_("Asia/Dili");
N_("Asia/Dubai");
N_("Asia/Dushanbe");
N_("Asia/Famagusta");
N_("Asia/Gaza");
N_("Asia/Hebron");
N_("Asia/Ho_Chi_Minh");
N_("Asia/Hong_Kong");
N_("Asia/Hovd");
N_("Asia/Irkutsk");
N_("Asia/Jakarta");
N_("Asia/Jayapura");
N_("Asia/Jerusalem");
N_("Asia/Kabul");
N_("Asia/Kamchatka");
N_("Asia/Karachi");
N_("Asia/Kathmandu");
N_("Asia/Khandyga");
N_("Asia/Kolkata");
N_("Asia/Krasnoyarsk");
N_("Asia/Kuching");
N_("Asia/Macau");
N_("Asia/Magadan");
N_("Asia/Makassar");
N_("Asia/Manila");
N_("Asia/Nicosia");
N_("Asia/Novokuznetsk");
N_("Asia/Novosibirsk");
N_("Asia/Omsk");
N_("Asia/Oral");
N_("Asia/Pontianak");
N_("Asia/Pyongyang");
N_("Asia/Qatar");
N_("Asia/Qostanay");
N_("Asia/Qyzylorda");
N_("Asia/Riyadh");
N_("Asia/Sakhalin");
N_("Asia/Samarkand");
N_("Asia/Seoul");
N_("Asia/Shanghai");
N_("Asia/Singapore");
N_("Asia/Srednekolymsk");
N_("Asia/Taipei");
N_("Asia/Tashkent");
N_("Asia/Tbilisi");
N_("Asia/Tehran");
N_("Asia/Thimphu");
N_("Asia/Tokyo");
N_("Asia/Tomsk");
N_("Asia/Ulaanbaatar");
N_("Asia/Urumqi");
N_("Asia/Ust-Nera");
N_("Asia/Vladivostok");
N_("Asia/Yakutsk");
N_("Asia/Yangon");
N_("Asia/Yekaterinburg");
N_("Asia/Yerevan");
N_("Atlantic/Azores");
N_("Atlantic/Bermuda");
N_("Atlantic/Canary");
N_("Atlantic/Cape_Verde");
N_("Atlantic/Faroe");
N_("Atlantic/Madeira");
N_("Atlantic/South_Georgia");
N_("Atlantic/Stanley");
N_("Australia/Adelaide");
N_("Australia/Brisbane");
N_("Australia/Broken_Hill");
N_("Australia/Darwin");
N_("Australia/Eucla");
N_("Australia/Hobart");
N_("Australia/Lindeman");
N_("Australia/Lord_Howe");
N_("Australia/Melbourne");
N_("Australia/Perth");
N_("Australia/Sydney");
N_("Etc/GMT");
N_("Etc/GMT+1");
N_("Etc/GMT+10");
N_("Etc/GMT+11");
N_("Etc/GMT+12");
N_("Etc/GMT+2");
N_("Etc/GMT+3");
N_("Etc/GMT+4");
N_("Etc/GMT+5");
N_("Etc/GMT+6");
N_("Etc/GMT+7");
N_("Etc/GMT+8");
N_("Etc/GMT+9");
N_("Etc/GMT-1");
N_("Etc/GMT-10");
N_("Etc/GMT-11");
N_("Etc/GMT-12");
N_("Etc/GMT-13");
N_("Etc/GMT-14");
N_("Etc/GMT-2");
N_("Etc/GMT-3");
N_("Etc/GMT-4");
N_("Etc/GMT-5");
N_("Etc/GMT-6");
N_("Etc/GMT-7");
N_("Etc/GMT-8");
N_("Etc/GMT-9");
N_("Etc/UTC");
N_("Europe/Andorra");
N_("Europe/Astrakhan");
N_("Europe/Athens");
N_("Europe/Belgrade");
N_("Europe/Berlin");
N_("Europe/Brussels");
N_("Europe/Bucharest");
N_("Europe/Budapest");
N_("Europe/Chisinau");
N_("Europe/Dublin");
N_("Europe/Gibraltar");
N_("Europe/Helsinki");
N_("Europe/Istanbul");
N_("Europe/Kaliningrad");
N_("Europe/Kirov");
N_("Europe/Kyiv");
N_("Europe/Lisbon");
N_("Europe/London");
N_("Europe/Madrid");
N_("Europe/Malta");
N_("Europe/Minsk");
N_("Europe/Moscow");
N_("Europe/Paris");
N_("Europe/Prague");
N_("Europe/Riga");
N_("Europe/Rome");
N_("Europe/Samara");
N_("Europe/Saratov");
N_("Europe/Simferopol");
N_("Europe/Sofia");
N_("Europe/Tallinn");
N_("Europe/Tirane");
N_("Europe/Ulyanovsk");
N_("Europe/Vienna");
N_("Europe/Vilnius");
N_("Europe/Volgograd");
N_("Europe/Warsaw");
N_("Europe/Zurich");
N_("Indian/Chagos");
N_("Indian/Maldives");
N_("Indian/Mauritius");
N_("Pacific/Apia");
N_("Pacific/Auckland");
N_("Pacific/Bougainville");
N_("Pacific/Chatham");
N_("Pacific/Easter");
N_("Pacific/Efate");
N_("Pacific/Fakaofo");
N_("Pacific/Fiji");
N_("Pacific/Galapagos");
N_("Pacific/Gambier");
N_("Pacific/Guadalcanal");
N_("Pacific/Guam");
N_("Pacific/Honolulu");
N_("Pacific/Kanton");
N_("Pacific/Kiritimati");
N_("Pacific/Kosrae");
N_("Pacific/Kwajalein");
N_("Pacific/Marquesas");
N_("Pacific/Nauru");
N_("Pacific/Niue");
N_("Pacific/Norfolk");
N_("Pacific/Noumea");
N_("Pacific/Pago_Pago");
N_("Pacific/Palau");
N_("Pacific/Pitcairn");
N_("Pacific/Port_Moresby");
N_("Pacific/Rarotonga");
N_("Pacific/Tahiti");
N_("Pacific/Tarawa");
N_("Pacific/Tongatapu");
